@@ -1,9 +1,12 @@
 # Copyright (c) 2007-2008 Infrae. All rights reserved.
-# $Id: Common.py 30442 2008-08-25 11:06:13Z sylvain $
+# $Id: Common.py 31670 2008-10-31 10:21:14Z sylvain $
 
 import os.path
 import re
 
+import zc.buildout
+
+
 def checkExistPath(path):
     """Check that a path exist.
     """
@@ -28,6 +31,16 @@ def prepareURLs(location, urls):
     return dict([prepareEntry(l) for l in urls.splitlines() if l.strip()])
 
 
+def extractNames(urls):
+    """Return just the target names of the urls (used for egg names)"""
+
+    def extractName(line):
+        link, name = line.split()
+        return name
+
+    return [extractName(line) for line in urls.splitlines() if line.strip()]
+
+
 class BaseRecipe(object):
     """infrae.subversion recipe. Base class.
     """
@@ -36,22 +49,28 @@ class BaseRecipe(object):
         self.buildout = buildout
         self.name = name
         self.options = options
-        
-        options['location'] = self.location = os.path.join(
-            buildout['buildout']['parts-directory'], self.name)
+        # location is overridable if desired.
+        location = options.get('location', None)
+        if location:
+            self.location = os.path.join(
+                buildout['buildout']['directory'], location)
+        else:
+            self.location = os.path.join(
+                buildout['buildout']['parts-directory'], self.name)
+        options['location'] = self.location
         self.revisions = {} # Store revision information for each link
         self.updated = []   # Store updated links
         self.urls = prepareURLs(self.location, options['urls'])
         self.export = options.get('export')
+        self.offline = buildout['buildout'].get('offline', 'false') == 'true'
+        self.eggify = options.get('as_eggs', False)
+        self.eggs = self.eggify and extractNames(options['urls']) or []
         self.newest = (
-            buildout['buildout'].get('offline', 'false') == 'false'
-            and
+            not self.offline and
             buildout['buildout'].get('newest', 'true') == 'true'
             )
         self.verbose = buildout['buildout'].get('verbosity', 0)
 
-
-
     def _exportInformationToOptions(self):
         """Export revision and changed information to options.
 
@@ -59,9 +78,11 @@ class BaseRecipe(object):
         """
         if self.options.get('export_info', False):
             self.options['updated'] = str('\n'.join(self.updated))
-            str_revisions = ['%s %s' % r for r in self.revisions.items() if r[1]]
+            str_revisions = ['%s %s' % r for r in self.revisions.items()
+                             if r[1]]
             self.options['revisions'] = str('\n'.join(sorted(str_revisions)))
-
+        # Always export egg list
+        self.options['eggs'] = '\n'.join(sorted(self.eggs))
 
     def _updateAllRevisionInformation(self):
         """Update all revision information for defined urls.
@@ -70,7 +91,6 @@ class BaseRecipe(object):
             if os.path.exists(path):
                 self._updateRevisionInformation(link, path)
 
-
     def _updateRevisionInformation(self, link, revision):
         """Update revision information on a path.
         """
@@ -79,13 +99,11 @@ class BaseRecipe(object):
         if not (old_revision is None):
             self.updated.append(link)
 
-
     def _updatePath(self, link, path):
         """Update a single path.
         """
         raise NotImplementedError
 
-
     def update(self):
         """Update the checkouts.
 
@@ -106,7 +124,7 @@ class BaseRecipe(object):
 
             if ignore:
                 continue
-            
+
             if num_release.match(link):
                 if self.verbose:
                     print "Given num release for %s, skipping." % link
@@ -115,17 +133,17 @@ class BaseRecipe(object):
             if self.verbose:
                 print "Updating %s" % path
             self._updatePath(link, path)
-            
+
+        if self.eggify:
+            self._eggify()
         self._exportInformationToOptions()
         return self.location
 
-
     def _installPath(self, link, path):
         """Checkout a single entry.
         """
         raise NotImplementedError
 
-
     def _installPathVerbose(self, link, path):
         """Checkout a single entry with verbose.
         """
@@ -133,7 +151,13 @@ class BaseRecipe(object):
             print "%s %s to %s" % (self.export and 'Export' or 'Fetch',
                                    link, path)
         self._installPath(link, path)
-                                   
+
+    def _eggify(self):
+        """Install everything as development eggs if eggs=true"""
+        if self.eggify:
+            target = self.buildout['buildout']['develop-eggs-directory']
+            for path in self.urls.keys():
+                zc.buildout.easy_install.develop(path, target)
 
     def install(self):
         """Checkout the checkouts.
@@ -143,8 +167,16 @@ class BaseRecipe(object):
 
         for path, link in self.urls.items():
             self._installPathVerbose(link, path)
+        installed = [self.location]
 
+        if self.eggify:
+            self._eggify()
+            # And also return the develop-eggs/*.egg-link files that are
+            # ours so that an uninstall automatically zaps them.
+            dev_dir = self.buildout['buildout']['develop-eggs-directory']
+            egg_links = ['%s.egg-link' % egg for egg in self.eggs]
+            egg_links = [os.path.join(dev_dir, link) for link in egg_links]
+            installed += egg_links
         self._exportInformationToOptions()
-        return self.location
-
 
+        return installed
